/************************************************************************************************/
/*                                                                                              */
/*      <cyberHotel: Gestion Hotelera GPL>                                                      */
/*      Copyright (C) <2008> <davide05@gmail.com>                                               */
/*                                                                                              */
/*      This program is free software: you can redistribute it and/or modify                    */
/*      it under the terms of the GNU General Public License as published by                    */
/*      the Free Software Foundation, either version 3 of the License, or                       */
/*      (at your option) any later version.                                                     */
/*                                                                                              */
/*      This program is distributed in the hope that it will be useful,                         */
/*      but WITHOUT ANY WARRANTY; without even the implied warranty of                          */
/*      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                                    */ 
/*      See the GNU General Public License for more details.                                    */
/*                                                                                              */
/*      You should have received a copy of the GNU General Public License                       */
/*      along with this program.  If not, see <http://www.gnu.org/licenses/>.                   */
/*                                                                                              */
/************************************************************************************************/

package gz.cyberbrain.cyberhotel.controller;

import gz.cyberbrain.cyberhotel.controller.util.ErrorItem;
import gz.cyberbrain.cyberhotel.controller.util.ErrorsHandler;
import gz.cyberbrain.cyberhotel.model.configurationfacade.delegate.ConfigurationFacadeDelegate;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.PriceTypeInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.PriceTypeTariffiedException;
import gz.cyberbrain.cyberhotel.model.pricetype.to.PriceTypeTo;
import gz.cyberbrain.cyberhotel.model.spring.facade.SpringFacadeFactory;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InstanceNotFoundException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InternalErrorException;
import gz.cyberbrain.cyberhotel.view.swing.util.gui.TextItem;

import java.io.Serializable;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Vector;

public class PriceTypeController {

	private static ConfigurationFacadeDelegate delegate = SpringFacadeFactory.getConfigurationFacadeDelegate();
	private static HashMap<String, String> attributes = new HashMap<String, String>();

	private PriceTypeController() {}

	public static Vector priceTypeList() throws InternalErrorException {				
		Vector<TextItem> items = new Vector<TextItem> ();
		Collection priceTypes = delegate.showPriceTypes();
		Iterator iter = priceTypes.iterator();

		PriceTypeTo priceType;

		for (int i=0; iter.hasNext(); i++) {

			priceType = (PriceTypeTo) iter.next();
			items.add(new TextItem(priceType.getPriceTypeCode(), priceType.getDescription()));

		}

		return items;
	}

	public static Serializable createPriceType(String priceTypeCode, String description) throws InternalErrorException {
		return delegate.createPriceType(new PriceTypeTo(priceTypeCode, description)).getPriceTypeCode();
	}

	public static void updatePriceType(String priceTypeCode, String description) throws InternalErrorException {		
		delegate.updatePriceType(new PriceTypeTo(priceTypeCode, description));
	}

	public static void deletePriceType(String priceTypeCode) throws PriceTypeInUseException, PriceTypeTariffiedException, InstanceNotFoundException,  InternalErrorException{
		PriceTypeTo priceType = delegate.findPriceType(priceTypeCode);
		delegate.deletePriceType(priceType);
	}

	public static HashMap findPriceType(String priceTypeCode) {
		PriceTypeTo priceType;

		try {

			priceType = delegate.findPriceType(priceTypeCode);

			attributes.put("code", priceTypeCode);
			attributes.put("description", priceType.getDescription());

		} catch (InstanceNotFoundException e) {
			ErrorsHandler.clear();
			ErrorsHandler.add(new ErrorItem("instanceNotFound"));
		} catch (InternalErrorException e) {
			e.printStackTrace();
		}


		return attributes;

	}

}
