/************************************************************************************************/
/*                                                                                              */
/*      <cyberHotel: Gestion Hotelera GPL>                                                      */
/*      Copyright (C) <2008> <davide05@gmail.com>                                               */
/*                                                                                              */
/*      This program is free software: you can redistribute it and/or modify                    */
/*      it under the terms of the GNU General Public License as published by                    */
/*      the Free Software Foundation, either version 3 of the License, or                       */
/*      (at your option) any later version.                                                     */
/*                                                                                              */
/*      This program is distributed in the hope that it will be useful,                         */
/*      but WITHOUT ANY WARRANTY; without even the implied warranty of                          */
/*      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                                    */ 
/*      See the GNU General Public License for more details.                                    */
/*                                                                                              */
/*      You should have received a copy of the GNU General Public License                       */
/*      along with this program.  If not, see <http://www.gnu.org/licenses/>.                   */
/*                                                                                              */
/************************************************************************************************/

package gz.cyberbrain.cyberhotel.controller;

import gz.cyberbrain.cyberhotel.model.configurationfacade.delegate.ConfigurationFacadeDelegate;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.SeasonTariffiedException;
import gz.cyberbrain.cyberhotel.model.day.to.DayTo;
import gz.cyberbrain.cyberhotel.model.season.to.SeasonTo;
import gz.cyberbrain.cyberhotel.model.spring.facade.SpringFacadeFactory;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InstanceNotFoundException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InternalErrorException;
import gz.cyberbrain.cyberhotel.view.swing.util.gui.LongItem;
import gz.cyberbrain.cyberhotel.view.swing.util.gui.TextItem;

import java.io.Serializable;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Vector;

public class SeasonController {

	private static ConfigurationFacadeDelegate delegate = SpringFacadeFactory.getConfigurationFacadeDelegate();
	private static HashMap<String, Object> attributes = new HashMap<String, Object>();

	private SeasonController() {}

	public static Vector seasonList() {				

		Vector<TextItem> items = new Vector<TextItem> ();
		try {
			Collection seasons;

			seasons = delegate.showSeasons();

			Iterator iter = seasons.iterator();

			SeasonTo season;

			for (int i=0; iter.hasNext(); i++) {

				season = (SeasonTo) iter.next();
				items.add(new TextItem(season.getSeasonId(), season.getName()));

			}
		} catch (InternalErrorException e) {
			e.printStackTrace();
		}
		return items;
	}

	public static Serializable createSeason(String name, String description) throws InternalErrorException {
		return delegate.createSeason(new SeasonTo(null, name, description)).getSeasonId();
	}

	public static void updateSeason(Long seasonId, String name, String description) throws InternalErrorException {		
		delegate.updateSeason(new SeasonTo(seasonId, name, description));
	}

	public static void deleteSeason(Long seasonId) throws SeasonTariffiedException, InstanceNotFoundException, InternalErrorException {
		SeasonTo season = delegate.findSeason(seasonId);
		delegate.deleteSeason(season);
	}

	public static HashMap findSeason(Long seasonId) throws InstanceNotFoundException, InternalErrorException {
		SeasonTo season = delegate.findSeason(seasonId);

		attributes.put("id", seasonId);
		attributes.put("name", season.getName());
		attributes.put("description", season.getDescription());

		return attributes;

	}

	public static void updateDaySeasons(Collection days, Long seasonId) {

		Calendar calendar = Calendar.getInstance();

		Iterator iter = days.iterator();

		for(int i=0; iter.hasNext(); i++) {

			calendar.setTime((Date) iter.next());
//			System.out.println("calendar " + calendar.getTime());
			try {
				delegate.updateDaySeason(new DayTo(calendar, seasonId));
			} catch (InternalErrorException e) {
				e.printStackTrace();
			}

		}

	}

	public static void removeDaySeasons(Collection days) 
	throws SeasonTariffiedException, InstanceNotFoundException, InternalErrorException {

		Calendar calendar = Calendar.getInstance();

		Iterator iter = days.iterator();

		for(int i=0; iter.hasNext(); i++) {

			calendar.setTime((Date) iter.next());

			delegate.deleteDaySeason(calendar); 

		}

	}
	public static Vector dayList() {

		Vector<LongItem> items = new Vector<LongItem> ();

		try {

			Collection days = delegate.showDays();

			Iterator iter = days.iterator();

			DayTo day;

			for (int i=0; iter.hasNext(); i++) {

				day = (DayTo) iter.next();
				items.add(new LongItem(day.getDayDate(), day.getSeason()));

			}

		} catch (InternalErrorException e) {
			e.printStackTrace();
		}

		return items;
	}

	public static Vector seasonDayList(Long seasonId) {

		Vector<LongItem> items = new Vector<LongItem> ();

		try {

			Collection days = delegate.showSeasonDays(seasonId);

			Iterator iter = days.iterator();

			DayTo day;

			for (int i=0; iter.hasNext(); i++) {

				day = (DayTo) iter.next();
				items.add(new LongItem(day.getDayDate(), day.getSeason()));

			}

		} catch (InternalErrorException e) {
			e.printStackTrace();
		}

		return items;
	}

}
