/************************************************************************************************/
/*                                                                                              */
/*      <cyberHotel: Gestion Hotelera GPL>                                                      */
/*      Copyright (C) <2008> <davide05@gmail.com>                                               */
/*                                                                                              */
/*      This program is free software: you can redistribute it and/or modify                    */
/*      it under the terms of the GNU General Public License as published by                    */
/*      the Free Software Foundation, either version 3 of the License, or                       */
/*      (at your option) any later version.                                                     */
/*                                                                                              */
/*      This program is distributed in the hope that it will be useful,                         */
/*      but WITHOUT ANY WARRANTY; without even the implied warranty of                          */
/*      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                                    */ 
/*      See the GNU General Public License for more details.                                    */
/*                                                                                              */
/*      You should have received a copy of the GNU General Public License                       */
/*      along with this program.  If not, see <http://www.gnu.org/licenses/>.                   */
/*                                                                                              */
/************************************************************************************************/

package gz.cyberbrain.cyberhotel.model.configurationfacade.delegate;

import gz.cyberbrain.cyberhotel.model.address.to.AddressTo;
import gz.cyberbrain.cyberhotel.model.bank.to.BankTo;
import gz.cyberbrain.cyberhotel.model.board.to.BoardTo;
import gz.cyberbrain.cyberhotel.model.card.to.CardTo;
import gz.cyberbrain.cyberhotel.model.concept.to.ConceptTo;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.AddressInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.BankWithClientsException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.BoardInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.BoardTariffiedException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.CardWithClientsException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.ConceptInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.EmployeeWithWashesException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.PriceTypeInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.PriceTypeTariffiedException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.RoomTypeInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.RoomWithBoardersException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.SeasonTariffiedException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.UnaceptableRoomTypeException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.UserInUseException;
import gz.cyberbrain.cyberhotel.model.day.to.DayTo;
import gz.cyberbrain.cyberhotel.model.employee.to.EmployeeTo;
import gz.cyberbrain.cyberhotel.model.price.to.PriceTo;
import gz.cyberbrain.cyberhotel.model.pricetype.to.PriceTypeTo;
import gz.cyberbrain.cyberhotel.model.room.to.RoomTo;
import gz.cyberbrain.cyberhotel.model.roomtype.to.RoomTypeTo;
import gz.cyberbrain.cyberhotel.model.season.to.SeasonTo;
import gz.cyberbrain.cyberhotel.model.user.to.UserTo;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InstanceNotFoundException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InternalErrorException;

import java.io.Serializable;
import java.util.Calendar;
import java.util.Collection;

public interface ConfigurationFacadeDelegate extends Serializable {	
	
	public AddressTo createAddress(AddressTo addressTo) throws InternalErrorException;		
	
	public void updateAddress(AddressTo addressTo) throws InternalErrorException;
	
	public void deleteAddress(AddressTo addressTo) throws AddressInUseException, InternalErrorException;
	
	public Collection showAddresses() throws InternalErrorException;
	
	public Collection showCountries() throws InternalErrorException;
	
	public Collection showCountryProvinces(String country) throws InternalErrorException;
	
	public Collection showProvinceLocalities(String country, String province) throws InternalErrorException;
	
	public AddressTo findAddress(Long addressId) throws InstanceNotFoundException, InternalErrorException;
	
	public AddressTo findByCompleteAddress(String country, String province, String locality) throws InstanceNotFoundException, InternalErrorException;
	
	public void deleteAddressByCountry(String country) throws AddressInUseException, InternalErrorException;
	
	public void deleteAddressByProvince(String country, String province) throws AddressInUseException, InternalErrorException;
	
	public void deleteAddressByLocality(String country, String province, String locality) throws AddressInUseException, InstanceNotFoundException, InternalErrorException;
	
	public BankTo createBank(BankTo bankTo) throws InternalErrorException;
	
	public BankTo findBank(Long bankId) throws InstanceNotFoundException, InternalErrorException;
	
	public void updateBank(BankTo bankTo) throws InternalErrorException;
	
	public void deleteBank(BankTo bankTo) throws BankWithClientsException, InternalErrorException;
	
	public Collection showBanks() throws InternalErrorException;
	
	public CardTo createCard(CardTo cardTo) throws InternalErrorException;
	
	public CardTo findCard(Long cardId) throws InstanceNotFoundException, InternalErrorException;
	
	public void updateCard(CardTo cardTo) throws InternalErrorException;
	
	public void deleteCard(CardTo cardTo) throws CardWithClientsException, InternalErrorException;
	
	public Collection showCards() throws InternalErrorException;
	
	public RoomTypeTo createRoomType(RoomTypeTo roomTypeTo) throws InternalErrorException;
	
	public RoomTypeTo findRoomType(String roomTypeCode) throws InstanceNotFoundException, InternalErrorException;
	
	public void updateRoomType(RoomTypeTo roomTypeTo) throws InternalErrorException;
	
	public void deleteRoomType(RoomTypeTo roomTypeTo) throws RoomTypeInUseException, InternalErrorException;
	
	public Collection showRoomTypes() throws InternalErrorException;
	
	public RoomTo createRoom(RoomTo roomTo) throws UnaceptableRoomTypeException, InternalErrorException;
	
	public RoomTo findRoom(String roomCode) throws InstanceNotFoundException, InternalErrorException;
	
	public void updateRoom(RoomTo roomTo) throws UnaceptableRoomTypeException, InternalErrorException;
	
	public void deleteRoom(RoomTo roomTo) throws RoomWithBoardersException, InternalErrorException;
	
	public Collection showRooms() throws InternalErrorException;	
	
	public BoardTo createBoard(BoardTo boardTo) throws InternalErrorException;
	
	public BoardTo findBoard(String boardCode) throws InstanceNotFoundException, InternalErrorException;
	
	public void updateBoard(BoardTo boardTo) throws InternalErrorException;
	
	public void deleteBoard(BoardTo boardTo) throws BoardInUseException, BoardTariffiedException, InternalErrorException;
	
	public Collection showBoards() throws InternalErrorException;	
	
	public PriceTypeTo createPriceType(PriceTypeTo priceTypeTo) throws InternalErrorException;
	
	public PriceTypeTo findPriceType(String priceTypeCode) throws InstanceNotFoundException, InternalErrorException;
	
	public void updatePriceType(PriceTypeTo priceTypeTo) throws InternalErrorException;
	
	public void deletePriceType(PriceTypeTo priceTypeTo) throws PriceTypeInUseException, PriceTypeTariffiedException, InternalErrorException;
	
	public Collection showPriceTypes() throws InternalErrorException;
	
	public SeasonTo createSeason(SeasonTo seasonTo) throws InternalErrorException;
	
	public SeasonTo findSeason(Long seasonId) throws InstanceNotFoundException, InternalErrorException;
	
	public void updateSeason(SeasonTo seasonTo) throws InternalErrorException;
	
	public void deleteSeason(SeasonTo seasonTo) throws SeasonTariffiedException, InternalErrorException;
	
	public Collection showSeasons() throws InternalErrorException;
	
	public void createPrice(PriceTo priceTo) throws InternalErrorException;	
	
	public PriceTo findPrice(Long priceId, String board, String priceType, Long season) throws InstanceNotFoundException, InternalErrorException;
	
	public void updatePrice (PriceTo priceTo) throws InternalErrorException;
	
	public void deletePrice (PriceTo priceTo) throws InternalErrorException;
	
	public Collection showSeasonPrices(Long season) throws InternalErrorException;
	
	public long maxPriceId() throws InternalErrorException;
	
	public DayTo createDay(DayTo dayTo) throws InternalErrorException;
	
	public void updateDay(DayTo dayTo) throws InternalErrorException;
	
	public void deleteDay(DayTo dayTo) throws InternalErrorException;
	
	public Collection showDays() throws InternalErrorException;
	
	public Collection showSeasonDays(Long seasonId) throws InternalErrorException;
	
	public void deleteDaySeason(Calendar dayDate) throws SeasonTariffiedException, InstanceNotFoundException, InternalErrorException;
	
	public void updateDaySeason(DayTo dayTo) throws InternalErrorException;
	
	public ConceptTo createConcept(ConceptTo conceptTo) throws InternalErrorException;
	
	public ConceptTo findConcept(String conceptCode) throws InstanceNotFoundException, InternalErrorException;
	
	public void updateConcept(ConceptTo conceptTo) throws InternalErrorException;
	
	public void deleteConcept(ConceptTo conceptTo) throws ConceptInUseException, InternalErrorException;
	
	public Collection showConcepts() throws InternalErrorException;
	
	public EmployeeTo createEmployee(EmployeeTo employeeTo) throws InternalErrorException;
	
	public EmployeeTo findEmployee(Long employeeId) throws InstanceNotFoundException, InternalErrorException;
	
	public void updateEmployee(EmployeeTo employeeTo) throws InternalErrorException;
	
	public void deleteEmployee(EmployeeTo employeeTo) throws EmployeeWithWashesException, InternalErrorException;
	
	public Collection showEmployees() throws InternalErrorException;	
	
	public UserTo registerUser(UserTo userTo) throws InternalErrorException;
	
	public void changePassword(String login, String newPassword) throws InstanceNotFoundException, InternalErrorException;
	
	public void removeUser(UserTo userTo) throws UserInUseException, InternalErrorException;
	
	public Collection usersList() throws InternalErrorException;
	
	public Collection rolesList() throws InternalErrorException;
	
}
