/************************************************************************************************/
/*                                                                                              */
/*      <cyberHotel: Gestion Hotelera GPL>                                                      */
/*      Copyright (C) <2008> <davide05@gmail.com>                                               */
/*                                                                                              */
/*      This program is free software: you can redistribute it and/or modify                    */
/*      it under the terms of the GNU General Public License as published by                    */
/*      the Free Software Foundation, either version 3 of the License, or                       */
/*      (at your option) any later version.                                                     */
/*                                                                                              */
/*      This program is distributed in the hope that it will be useful,                         */
/*      but WITHOUT ANY WARRANTY; without even the implied warranty of                          */
/*      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                                    */ 
/*      See the GNU General Public License for more details.                                    */
/*                                                                                              */
/*      You should have received a copy of the GNU General Public License                       */
/*      along with this program.  If not, see <http://www.gnu.org/licenses/>.                   */
/*                                                                                              */
/************************************************************************************************/

package gz.cyberbrain.cyberhotel.model.invoicingfacade.delegate;

import gz.cyberbrain.cyberhotel.model.cash.to.CashTo;
import gz.cyberbrain.cyberhotel.model.client.to.ClientTo;
import gz.cyberbrain.cyberhotel.model.invoice.to.InvoiceTo;
import gz.cyberbrain.cyberhotel.model.invoicingfacade.exceptions.ClosedPaymentException;
import gz.cyberbrain.cyberhotel.model.invoicingfacade.exceptions.IssuedInvoiceException;
import gz.cyberbrain.cyberhotel.model.invoicingfacade.exceptions.UnaceptableOweException;
import gz.cyberbrain.cyberhotel.model.invoicingfacade.exceptions.UnaceptablePayerException;
import gz.cyberbrain.cyberhotel.model.invoicingfacade.exceptions.UnaceptablePaymentException;
import gz.cyberbrain.cyberhotel.model.invoicingfacade.spring.actions.ClosedCashException;
import gz.cyberbrain.cyberhotel.model.invoicingfacade.spring.actions.PayedInvoiceException;
import gz.cyberbrain.cyberhotel.model.payment.to.PaymentTo;
import gz.cyberbrain.cyberhotel.model.reservationfacade.exceptions.UnaceptableInvoiceException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InstanceNotFoundException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InternalErrorException;

import java.io.Serializable;
import java.util.Collection;

public interface InvoicingFacadeDelegate extends Serializable {

	public InvoiceTo insertAnInvoice(InvoiceTo invoiceTo, Collection oweNumbers) 
	throws UnaceptablePayerException, UnaceptableOweException, InstanceNotFoundException, InternalErrorException;

	public InvoiceTo findAnInvoice(Long invoiceNumber, String invoiceSerial) 
	throws InstanceNotFoundException, InternalErrorException;

	public void updateAnInvoice(InvoiceTo invoiceTo, Collection oweNumbers) 
	throws UnaceptablePayerException, UnaceptableOweException, InstanceNotFoundException, InternalErrorException;

	public void deleteAnInvoice(InvoiceTo invoiceTo) throws PayedInvoiceException, InstanceNotFoundException, InternalErrorException;

	public Collection showInvoices() throws InternalErrorException;

	public Collection findOutstandingInvoices() throws InternalErrorException;

	public Collection findIssuedInvoices() throws InternalErrorException;

	public ClientTo findAPayer(Long clientId) throws InstanceNotFoundException, InternalErrorException;

	public Collection findInvoiceOwes(Long invoiceNumber, String invoiceSerial) throws InternalErrorException;

	public PaymentTo insertAPayment(PaymentTo paymentTo, boolean issue) 
	throws UnaceptableInvoiceException, IssuedInvoiceException, InstanceNotFoundException, InternalErrorException;

	public PaymentTo findAPayment(Long reference) throws InstanceNotFoundException, InternalErrorException;

	public void updateAPayment(PaymentTo paymentTo) 
	throws ClosedPaymentException, UnaceptableInvoiceException, IssuedInvoiceException, InstanceNotFoundException, InternalErrorException;

	public void deleteAPayment(PaymentTo paymentTo) throws InstanceNotFoundException, InternalErrorException;

	public Collection showPayments() throws InternalErrorException;
	
	public Collection findOpenedPayments() throws InternalErrorException;

	public CashTo insertACash(CashTo cashTo) 
	throws InstanceNotFoundException, InternalErrorException;

	public CashTo findACash(Long cashNumber) throws InstanceNotFoundException, InternalErrorException;

	public void updateACash(CashTo cashTo, Collection payments, boolean closement) 
	throws ClosedCashException, UnaceptablePaymentException, ClosedPaymentException, InstanceNotFoundException, InternalErrorException;

	public Collection showCashes() throws InternalErrorException;

}
