/************************************************************************************************/
/*                                                                                              */
/*      <cyberHotel: Gestion Hotelera GPL>                                                      */
/*      Copyright (C) <2008> <davide05@gmail.com>                                               */
/*                                                                                              */
/*      This program is free software: you can redistribute it and/or modify                    */
/*      it under the terms of the GNU General Public License as published by                    */
/*      the Free Software Foundation, either version 3 of the License, or                       */
/*      (at your option) any later version.                                                     */
/*                                                                                              */
/*      This program is distributed in the hope that it will be useful,                         */
/*      but WITHOUT ANY WARRANTY; without even the implied warranty of                          */
/*      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                                    */ 
/*      See the GNU General Public License for more details.                                    */
/*                                                                                              */
/*      You should have received a copy of the GNU General Public License                       */
/*      along with this program.  If not, see <http://www.gnu.org/licenses/>.                   */
/*                                                                                              */
/************************************************************************************************/

package gz.cyberbrain.cyberhotel.model.price.dao;

import gz.cyberbrain.cyberhotel.model.price.to.PriceTo;
import gz.cyberbrain.cyberhotel.model.spring.dao.AbstractSpringDao;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InstanceNotFoundException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InternalErrorException;
import java.io.Serializable;
import java.util.Collection;
import java.util.Iterator;

public class PriceSpringDao extends AbstractSpringDao implements PriceDao {

	public PriceSpringDao() {
		super(PriceTo.class);
	}	

	public void create(PriceTo priceTo) throws InternalErrorException {		

		super.save(priceTo);

	}

	public PriceTo find(Long priceId, String board, String priceType, Long season) throws InstanceNotFoundException, InternalErrorException {

		String queryName = "aPrice";
		Serializable []attributes = {priceId, board, priceType, season}; 
		Collection priceTo = super.findByAttributes(queryName,attributes);

		Exception e = new Exception("Price must be unique");

		if (priceTo.size() > 1) throw new InternalErrorException(e);
		if (priceTo.isEmpty()) throw new InstanceNotFoundException(attributes,PriceTo.class.getName());

		Iterator iter = priceTo.iterator();

		return (PriceTo) iter.next();

	}

	public void update(PriceTo priceTo) throws InternalErrorException {		

		super.update(priceTo);

	}

	public void remove(PriceTo priceTo) throws InternalErrorException {

		super.delete(priceTo);

	}

	public Collection findAll() throws InternalErrorException {

		String queryName = "allPrices";
		return super.findByQuery(queryName);

	}

	public Collection findBySeason(Long season) throws InternalErrorException {

		String queryName = "findBySeason";
		return super.findByAttribute(queryName, season);
	}

	public long maxId() throws InternalErrorException {

		String queryName = "nextId";
		Collection id = super.findByQuery(queryName);
		if (id.size() > 1) throw new InternalErrorException(new Exception());
		Iterator iter = id.iterator();		
		return ((Long) iter.next()).longValue();

	}

}
