/************************************************************************************************/
/*                                                                                              */
/*      <cyberHotel: Gestion Hotelera GPL>                                                      */
/*      Copyright (C) <2008> <davide05@gmail.com>                                               */
/*                                                                                              */
/*      This program is free software: you can redistribute it and/or modify                    */
/*      it under the terms of the GNU General Public License as published by                    */
/*      the Free Software Foundation, either version 3 of the License, or                       */
/*      (at your option) any later version.                                                     */
/*                                                                                              */
/*      This program is distributed in the hope that it will be useful,                         */
/*      but WITHOUT ANY WARRANTY; without even the implied warranty of                          */
/*      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                                    */ 
/*      See the GNU General Public License for more details.                                    */
/*                                                                                              */
/*      You should have received a copy of the GNU General Public License                       */
/*      along with this program.  If not, see <http://www.gnu.org/licenses/>.                   */
/*                                                                                              */
/************************************************************************************************/

package gz.cyberbrain.cyberhotel.model.reservationfacade.spring.actions;

import gz.cyberbrain.cyberhotel.model.address.dao.AddressDao;
import gz.cyberbrain.cyberhotel.model.bank.dao.BankDao;
import gz.cyberbrain.cyberhotel.model.card.dao.CardDao;
import gz.cyberbrain.cyberhotel.model.client.dao.ClientDao;
import gz.cyberbrain.cyberhotel.model.client.to.AgencyTo;
import gz.cyberbrain.cyberhotel.model.reservationfacade.exceptions.InvalidPayModeException;
import gz.cyberbrain.cyberhotel.model.reservationfacade.exceptions.UnaceptableAddressException;
import gz.cyberbrain.cyberhotel.model.reservationfacade.exceptions.UnaceptableBankException;
import gz.cyberbrain.cyberhotel.model.reservationfacade.exceptions.UnaceptableCardException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InstanceNotFoundException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InternalErrorException;

public class UpdateAnAgencyAction {

	private AgencyTo agencyTo;
	private AddressDao addressDao;
	private BankDao bankDao;
	private CardDao cardDao;
	private ClientDao agencyDao;

	public UpdateAnAgencyAction(AgencyTo agencyTo, AddressDao addressDao, BankDao bankDao, CardDao cardDao, ClientDao agencyDao) {
		this.agencyTo = agencyTo;
		this.addressDao = addressDao;
		this.bankDao = bankDao;
		this.cardDao = cardDao;
		this.agencyDao = agencyDao;
	}

	public void execute() 
	throws InvalidPayModeException, UnaceptableAddressException, 
	UnaceptableBankException, UnaceptableCardException,
	InternalErrorException {

		try {
			addressDao.find(agencyTo.getAddress());
		} catch (InstanceNotFoundException e) {
			throw new UnaceptableAddressException(agencyTo.getAddress());
		}

		try {
			bankDao.find(agencyTo.getBank());
		} catch (InstanceNotFoundException e) {
			throw new UnaceptableBankException(agencyTo.getBank());
		}

		try {
			cardDao.find(agencyTo.getCard());
		} catch (InstanceNotFoundException e) {
			throw new UnaceptableCardException(agencyTo.getCard());
		}

		if (agencyTo.getPayMode() != "Contado"
				&& agencyTo.getPayMode() != "Tarxeta"
					&& agencyTo.getPayMode() != "Bono") throw new InvalidPayModeException(agencyTo.getPayMode()); 

		agencyDao.update(agencyTo);

	}


}
