/************************************************************************************************/
/*                                                                                              */
/*      <cyberHotel: Gestion Hotelera GPL>                                                      */
/*      Copyright (C) <2008> <davide05@gmail.com>                                               */
/*                                                                                              */
/*      This program is free software: you can redistribute it and/or modify                    */
/*      it under the terms of the GNU General Public License as published by                    */
/*      the Free Software Foundation, either version 3 of the License, or                       */
/*      (at your option) any later version.                                                     */
/*                                                                                              */
/*      This program is distributed in the hope that it will be useful,                         */
/*      but WITHOUT ANY WARRANTY; without even the implied warranty of                          */
/*      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                                    */ 
/*      See the GNU General Public License for more details.                                    */
/*                                                                                              */
/*      You should have received a copy of the GNU General Public License                       */
/*      along with this program.  If not, see <http://www.gnu.org/licenses/>.                   */
/*                                                                                              */
/************************************************************************************************/

package gz.cyberbrain.cyberhotel.view.swing.login;

import gz.cyberbrain.cyberhotel.security.SecurityHandler;
import gz.cyberbrain.cyberhotel.view.swing.start.MainWindow;
import gz.cyberbrain.cyberhotel.view.swing.start.SplashScreen;
import gz.cyberbrain.cyberhotel.view.swing.util.locale.Locale;

import java.awt.Color;
import java.awt.GraphicsEnvironment;
import java.awt.Rectangle;

import javax.swing.JPanel;
import javax.swing.JLabel;
import javax.swing.JFrame;
import javax.swing.JRootPane;
import javax.swing.JTextField;
import javax.swing.JPasswordField;
import javax.swing.JButton;

import org.acegisecurity.BadCredentialsException;

public class LoginWindow extends JFrame {

	private static final long serialVersionUID = 1L;
	private static LoginWindow loginWindow;
	private JPanel jContentPane = null;  
	private JLabel loginLabel = null;
	private JLabel passwordLabel = null;
	private JTextField loginTextField = null;
	private JPasswordField jPasswordField = null;
	private JButton loginButton = null;  
	private JButton exitButton = null;
	private JLabel errorsLabel = null;
	private JLabel separatorLabel = null;
	private JLabel logoLabel = null;
	private SplashScreen splashScreen = SplashScreen.getInstance();

	/**
	 * @param owner
	 */
	private LoginWindow() {
		super();	
		initialize();
	}

	public static LoginWindow getInstance() {
		if (loginWindow == null) loginWindow = new LoginWindow();
		return loginWindow;
	}

	/**
	 * This method initializes this
	 * 
	 * @return void
	 */
	private void initialize() {		
		GraphicsEnvironment graphicsEnvironment=GraphicsEnvironment.getLocalGraphicsEnvironment();
		Rectangle maximumWindowBounds=graphicsEnvironment.getMaximumWindowBounds();
		this.setSize(java.lang.Math.round(new Float((2./3)*maximumWindowBounds.width)), java.lang.Math.round(new Float((2./3)*maximumWindowBounds.height)));
		this.setLocation(java.lang.Math.round(new Float((1./6)*maximumWindowBounds.width)), java.lang.Math.round(new Float((1./6)*maximumWindowBounds.height)));	
		splashScreen.increase(20);		
		splashScreen.setInfoText(Locale.get("SplashScreen.windowEnvironment"));
		this.setContentPane(getJContentPane());		
		this.setUndecorated(true);
		this.getRootPane().setWindowDecorationStyle(JRootPane.FRAME);
		this.setTitle(Locale.get("MainWindow.title"));		
	}

	/**
	 * This method initializes jContentPane
	 * 
	 * @return javax.swing.JPanel
	 */
	private JPanel getJContentPane() {
		if (jContentPane == null) {
			logoLabel = new JLabel();
			logoLabel.setBounds(new Rectangle(499, 26, 208, 63));
			logoLabel.setText("");
			//logoLabel.setIcon(new ImageIcon("C:\\cyberHotel2.jpg"));
			separatorLabel = new JLabel();
			separatorLabel.setBounds(new Rectangle(457, 28, 21, 429));
			separatorLabel.setText("");
			//separatorLabel.setIcon(new ImageIcon("C:\\separador.jpg"));
			errorsLabel = new JLabel();		
			errorsLabel.setBounds(new Rectangle(501, 370, 161, 16));
			errorsLabel.setText("");
			passwordLabel = new JLabel();
			passwordLabel.setBounds(new Rectangle(500, 430, 80, 16));
			passwordLabel.setText(Locale.get("LoginWindow.passwordLabel"));
			loginLabel = new JLabel();
			loginLabel.setBounds(new Rectangle(500, 400, 40, 16));
			loginLabel.setText(Locale.get("LoginWindow.loginLabel"));
			splashScreen.increase(40);
			splashScreen.setInfoText(Locale.get("SplashScreen.loginWindow"));
			jContentPane = new JPanel();
			jContentPane.setLayout(null);
			jContentPane.setBackground(Color.BLUE);
			jContentPane.add(loginLabel, null);
			jContentPane.add(passwordLabel, null);
			jContentPane.add(getLoginTextField(), null);
			jContentPane.add(getJPasswordField(), null);
			jContentPane.add(getLoginButton(),null);
			jContentPane.add(getExitButton(), null);
			splashScreen.increase(20);			
			jContentPane.add(errorsLabel, null);
			jContentPane.add(separatorLabel, null);
			jContentPane.add(logoLabel, null);
			
		}
		return jContentPane;
	}

	/**
	 * This method initializes loginTextField	
	 * 	
	 * @return javax.swing.JTextField	
	 */
	private JTextField getLoginTextField() {
		if (loginTextField == null) {
			loginTextField = new JTextField();
			loginTextField.setBounds(new Rectangle(567, 400, 95, 20));
		}
		return loginTextField;
	}

	/**
	 * This method initializes jPasswordField	
	 * 	
	 * @return javax.swing.JPasswordField	
	 */
	private JPasswordField getJPasswordField() {
		if (jPasswordField == null) {
			jPasswordField = new JPasswordField();
			jPasswordField.setBounds(new Rectangle(567, 430, 95, 20));
		}
		return jPasswordField;
	}

	/**
	 * This method initializes loginButton	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getLoginButton() {
		if (loginButton == null) {
			loginButton = new JButton();
			loginButton.setText(Locale.get("LoginWindow.loginButton"));
			loginButton.setBounds(new Rectangle(500,460,75, 16));
			loginButton.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {																									

					try {

						SecurityHandler.setSecureContext(loginTextField.getText(), new String(jPasswordField.getPassword()));

						MainWindow mainWindow = MainWindow.getInstance();														
						mainWindow.setVisible(true);

						LoginWindow loginWindow = LoginWindow.getInstance();
						loginWindow.setVisible(false);

					} catch (BadCredentialsException f) {						
						errorsLabel.setText(Locale.get("LoginWindow.errorsLabel"));
						errorsLabel.setForeground(Color.RED);

						LoginWindow loginWindow = LoginWindow.getInstance();
						loginWindow.shake();
					}
				}
			});
		}
		return loginButton;
	}

	/**
	 * This method initializes exitButton	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getExitButton() {
		if (exitButton == null) {
			exitButton = new JButton();
			exitButton.setText(Locale.get("LoginWindow.exitButton"));
			exitButton.setBounds(new Rectangle(587,460,75, 16));
			exitButton.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					LoginWindow loginWindow = LoginWindow.getInstance();
					loginWindow.setVisible(false);
					loginWindow.dispose();

				}
			});
		}
		return exitButton;
	}

	private void shake() {
		LoginWindow loginWindow = LoginWindow.getInstance();

		for (int i=0; i<8; i++) {

			loginWindow.setLocation(loginWindow.getX()-15, loginWindow.getY());
			loginWindow.setLocation(loginWindow.getX()+15, loginWindow.getY());
			loginWindow.setLocation(loginWindow.getX()+15, loginWindow.getY());
			loginWindow.setLocation(loginWindow.getX()-15, loginWindow.getY());

		}

	}

}
